( cd usr/lib/purple-2 ; rm -rf libjabber.so.0 )
( cd usr/lib/purple-2 ; ln -sf libjabber.so.0.0.0 libjabber.so.0 )
( cd usr/lib/purple-2 ; rm -rf libjabber.so )
( cd usr/lib/purple-2 ; ln -sf libjabber.so.0.0.0 libjabber.so )
( cd usr/lib/purple-2 ; rm -rf liboscar.so.0 )
( cd usr/lib/purple-2 ; ln -sf liboscar.so.0.0.0 liboscar.so.0 )
( cd usr/lib/purple-2 ; rm -rf liboscar.so )
( cd usr/lib/purple-2 ; ln -sf liboscar.so.0.0.0 liboscar.so )
( cd usr/lib/purple-2 ; rm -rf libymsg.so.0 )
( cd usr/lib/purple-2 ; ln -sf libymsg.so.0.0.0 libymsg.so.0 )
( cd usr/lib/purple-2 ; rm -rf libymsg.so )
( cd usr/lib/purple-2 ; ln -sf libymsg.so.0.0.0 libymsg.so )
( cd usr/lib ; rm -rf libpurple.so.0 )
( cd usr/lib ; ln -sf libpurple.so.0.7.11 libpurple.so.0 )
( cd usr/lib ; rm -rf libpurple.so )
( cd usr/lib ; ln -sf libpurple.so.0.7.11 libpurple.so )
( cd usr/lib ; rm -rf libpurple-client.so.0 )
( cd usr/lib ; ln -sf libpurple-client.so.0.7.11 libpurple-client.so.0 )
( cd usr/lib ; rm -rf libpurple-client.so )
( cd usr/lib ; ln -sf libpurple-client.so.0.7.11 libpurple-client.so )
( cd usr/lib ; rm -rf libgnt.so.0 )
( cd usr/lib ; ln -sf libgnt.so.0.0.0 libgnt.so.0 )
( cd usr/lib ; rm -rf libgnt.so )
( cd usr/lib ; ln -sf libgnt.so.0.0.0 libgnt.so )
